@@ -3,7 +3,7 @@ from distutils.dir_util import copy_tree
 from pathlib import Path
 
 
-SKEL_PATH = Path(__file__).parents[1] / Path("skeleton")
+SKEL_PATH = Path(__file__).parent / Path("skeleton")
 
 
 def initialize():
