@@ -1,6 +1,6 @@
+from . import log
 import nbformat
 import re
-import logging
 import markdown
 from pathlib import Path
 from pprint import pformat
@@ -9,9 +9,6 @@ from bs4 import BeautifulSoup
 import frontmatter
 import sys
 
-log = logging.getLogger(__name__)
-logging.basicConfig(level=logging.INFO)
-
 
 class Page:
     """An abstract class for a static web page"""
@@ -64,7 +61,7 @@ class HomePage(Page):
         nb = nbformat.read(str(path), as_version=4)
 
         if nb.cells[0].cell_type != 'markdown':
-            log.error(f"The first cell of the notebook {path} should be Markdown type " + 
+            log.error(f"The first cell of the notebook {path} should be Markdown type " +
                       f"({nb.cells[0].cell_type} instead).")
             sys.exit()
         lines = nb.cells[0].source.splitlines()
